############################################################
Welcome to GeoBIPy: Geophysical Bayesian Inference in Python
############################################################

This package uses a Bayesian formulation and Markov chain Monte Carlo sampling methods to
derive posterior distributions of subsurface and measured data properties.
The current implementation is applied to time and frequency domain electromagnetic data.
Application outside of these data types is in development.

Citation
~~~~~~~~

Foks, N. L., and Minsley, B. J. 2020. GeoBIPy - Geophysical Bayesian Inference in Python. 10.5066/P9K3YH9O

Background scientific references
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Minsley, B. J., Foks, N. L., and Bedrosian, P. A. 2020. Quantifying model structural uncertainty using airborne electromagnetic data. Geophys. J. Int. 224, 1, 590–607. https://doi.org/10.1093/gji/ggaa393

Minsley, B. J. 2011. A trans-dimensional Bayesian Markov chain Monte Carlo algorithm for model assessment using frequency-domain electromagnetic data. Geophys. J. Int. 187, 252–272. 10.1111/j.1365-246X.2011.05165.x

`Documentation is here! <https://doi-usgs.github.io/geobipy/>`_

This software is preliminary or provisional and is subject to revision. It is being provided to meet the need for timely best science. The software has not received final approval by the U.S. Geological Survey (USGS). No warranty, expressed or implied, is made by the USGS or the U.S. Government as to the functionality of the software and related material nor shall the fact of release constitute any such warranty. The software is provided on the condition that neither the USGS nor the U.S. Government shall be held liable for any damages resulting from the authorized or unauthorized use of the software.
